function [] = generate_node_file(filepath, coord, n_color, n_size, labels)
%GENERATE_NODE_FILE     Write a txt .node file for BrainNet Viewer visualization.
%
%   generate_node_file(filepath, coord, n_color, n_size);
%   generate_node_file(filepath, coord, n_color, n_size, labels);
%   
%   The node file is defined as an ASCII text with the suffix ‘node’. 
%   In the file, there are 6 columns: columns 1-3 represent node
%   coordinates, column 4 represents node colors, column 5 represents node
%   size, column 6 represents node labels. A symbol '-' in column 6 
%   represents no label.
%   https://www.nitrc.org/projects/bnv/
%   Xia M, Wang J, He Y (2013) BrainNet Viewer: A network visualization
%   tool for human brain conectomics. PLoS ONE 8:e68910.
%
%   Inputs: filepath,
%               output file path (must have extension '.node')
%           coord,
%               node x,y,z coordinates (1 node per array row, 3 columns)
%           n_color,
%               node colors (1 scalar value per node)
%           n_size,
%               node sizes (1 scalar value per node)
%           labels,
%               optional argument,
%               node labels (1 string per node; it should not contain empty
%               strings)
%
%   Alessandra Griffa, UMC Utrecht, 2017

% Number of nodes
nn = length(n_size);

% Optional arguments
if ~exist('labels','var')
    labels = cell(nn, 1);
    labels(:) = {'-'};
end

% Write output text file
fid = fopen(filepath,'wt');
for i = 1:1:nn
    fprintf(fid, '%f %f %f %f %f %s\n', coord(i,1), coord(i,2), coord(i,3),...
        n_color(i), n_size(i), labels{i});
end
fclose(fid);





